@@ -3,10 +3,10 @@
 
 int main()
 {
-  register int n;
-  register char *x;
+  int n;
+  char *x;
   char ch;
-  register int flagcr = 0;
+  int flagcr = 0;
 
   for (;;) {
     n = buffer_feed(buffer_0);
