@@ -15,7 +15,7 @@ buffer bo;
 char inbuf[512];
 buffer bi;
 
-ssize_t myread(int fd,char *buf,int len)
+ssize_t myread(int fd,char *buf,size_t len)
 {
   buffer_flush(&bo);
   return read(fd,buf,len);
