@@ -216,11 +216,13 @@ void rblinfo(void)
   if (!pathexec_env("RBLSMTPD",info.s)) nomem();
 }
 
-void reject() { buffer_putflush(&out,message.s,message.len); }
-void accept() { buffer_putsflush(&out,"250 rblsmtpd.local\r\n"); }
-void greet()  { buffer_putsflush(&out,"220 rblsmtpd.local\r\n"); }
-void quit()   { buffer_putsflush(&out,"221 rblsmtpd.local\r\n"); _exit(0); }
-void drop()   { _exit(0); }
+// Needs to be same signature like in qmail-smtpd
+
+void reject(char *d) { buffer_putflush(&out,message.s,message.len); }
+void accept(char *d) { buffer_putsflush(&out,"250 rblsmtpd.local\r\n"); }
+void greet(char *d)  { buffer_putsflush(&out,"220 rblsmtpd.local\r\n"); }
+void quit(char *d)   { buffer_putsflush(&out,"221 rblsmtpd.local\r\n"); _exit(0); }
+void drop(char *d)   { _exit(0); }
 
 struct commands smtpcommands[] = {
   { "quit", quit, 0 }
@@ -235,6 +237,7 @@ struct commands smtpcommands[] = {
 void rblsmtpd(void)
 {
   int i;
+  char *dummy = 0;
 
   if (flagmustnotbounce || (decision == 2) || (decision == 4)) {
     if (!stralloc_copys(&message,"451 ")) nomem();
@@ -259,11 +262,11 @@ void rblsmtpd(void)
   if (!stralloc_cats(&message,"\r\n")) nomem();
 
   if (!timeout)
-    reject();
+    reject(dummy);
   else {
-    sig_catch(sig_alarm,drop);
+    sig_catch(sig_alarm,(void *)drop);
     alarm(timeout);
-    greet();
+    greet(dummy);
     commands(&in,smtpcommands);
   }
   _exit(0);
@@ -292,7 +295,7 @@ int main(int argc,char * const *argv,char * const *envp)
   }
 
   while ((opt = getoptb(argc,argv,"bBcCit:r:a:w:W")) != opteof)
-    switch(opt) {
+    switch (opt) {
       case 'b': flagrblbounce = 1; break;
       case 'B': flagrblbounce = 0; break;
       case 'c': flagfailclosed = 1; break;
