@@ -258,7 +258,7 @@ void doit(int t)
   }   
         
   if (flagdeny) goto FINISH; 
-  if (flagallow) fnrules = 0;
+  if (flagallow) fnrules = 0;  // you need to know what you are doing
 
   if (flagremotehost)
     if (dns_name(&remotehostsa,remoteip) >= 0)
